Skip to contents

Full (untrimmed) linelist data of Campylobacter surveillance in Germany 2001-2011.

Usage

campylobacter_germany_epirh

Format

A data frame with 522 rows and 2 columns

This data was originally added to the surveillance package and only kept date and cases variables. The data on campylobacteriosis cases have been queried from the "SurvstatRKI" database of the German Robert Koch Institute (https://survstat.rki.de/).

The original dataset can be accessed using data("CampyDe"). Within this package the original dataset is campylobacter_germany_epirh.xlsx

This is version 1.0.

This dataset is English.

This dataset is licensed under GPL3

Details

Weekly number of reported campylobacteriosis cases in Germany, 2001-2011. Unlike campylobacter_germany, this version keeps the full series and is prepared for use in the epiRhandbook time series chapter, alongside germany_weather.

References

Manitz, J. and Höhle, M. (2013): Bayesian outbreak detection algorithm for monitoring reported cases of campylobacteriosis in Germany. Biometrical Journal, 55(4), 509-526 doi:10.1002/bimj.201200141