Skip to contents

Incomplete data dictionary used for demonstrating cleaning of the raw version of fictional case linelist data simulating properties from the West African Ebola outbreak of 2014

Usage

case_linelists_cleaning_dict

Format

A data frame with 9 rows and 3 columns

This has been created as an example for use with case_linelists_linelist_raw, which is cleaned using code in the epiRhandbook cleaning chapter.

The original dataset is case_linelists_cleaning_dict.csv

This is version 1.0.

This dataset is English.

This dataset is licensed under MIT

Details

This is fictional data dictionary which contains recoding information. Same content as cleaning_dict, repackaged under the case_linelists_ naming for this bundle.

References

WHO Ebola Response Team. 2014. Ebola virus disease in West Africa–the first 9 months of the epidemic and forward projections. The New England journal of medicine 371:1481–1495 doi:10.1056/NEJMoa1411100