Skip to contents

Outputs from epinow2 based on fictional Ebola Virus Disease data simulating properties from the West African Ebola outbreak of 2014, repackaged for the epidemic models example.

Usage

epidemic_models_epinow_res

epidemic_models_epinow_res_small

epidemic_models_generation_time

epidemic_models_incubation_period

Format

A large list

The original dataset is epidemic_models_epinow_res.rds

This is version 1.0.

This dataset is English.

This dataset is licensed under MIT

Details

These outputs are produced using linelist_cleaned_rds with epinow2. Same content as epinow_res.