Skip to contents

Posterior samples of estimated reported cases, unbundled from epidemic_models_epinow_res ($estimated_reported_cases$samples) for the epidemic models example.

Usage

epidemic_models_estimated_reported_cases_samples

Format

A data frame with 308320 rows and 4 columns

The original dataset is epidemic_models_estimated_reported_cases_samples.rds

This is version 1.0.

This dataset is English.

This dataset is licensed under MIT

Details

See epidemic_models_epinow_res for the full model output this was extracted from.