Reported case counts, fictional Ebola outbreak in Sierra Leone (2014) - epidemic models example
epidemic_models_reported_cases.RdObserved case counts, unbundled from epidemic_models_epinow_res
($estimates$observations) for the epidemic models example.
The original dataset is epidemic_models_reported_cases.rds
This is version 1.0.
This dataset is English.
This dataset is licensed under MIT
Details
See epidemic_models_epinow_res for the full model output this was extracted from.