Summarised estimates, fictional Ebola outbreak in Sierra Leone (2014) - epidemic models example
epidemic_models_summarised_estimates.RdSummarised epinow2 estimates, unbundled from
epidemic_models_epinow_res ($estimates$summarised) for the epidemic
models example.
The original dataset is epidemic_models_summarised_estimates.rds
This is version 1.0.
This dataset is English.
This dataset is licensed under MIT
Details
See epidemic_models_epinow_res for the full model output this was extracted from.