Skip to contents

Central Hospital subset of the cleaned fictional Ebola Virus Disease case linelist, one of six per-hospital files prepared for an iteration/loops example where multiple files are read in and combined.

Usage

example_central_hospital

Format

A data frame with 454 rows and 30 columns

Within this package the original dataset is example_central_hospital.csv.

This is version 1.0.

This dataset is English.

This dataset is licensed under MIT

References

WHO Ebola Response Team. 2014. Ebola virus disease in West Africa–the first 9 months of the epidemic and forward projections. The New England journal of medicine 371:1481–1495 doi:10.1056/NEJMoa1411100