Feveriosis surveillance data from Viraland from Jan 1 2025 to Aug 31 2026 \(Spanish\)
feveriosis_main_es.RdSpanish version of the surveillance data for fictional disease feveriosis. Reported in fictional country Viraland in 2025 & 2026.
Fictional data created by Applied Epi for training purposes
This is version 1.1
This dataset is Spanish.
This dataset is licensed under CC by-NC-SA 4.0
Details
This is a linelist with fictional case-level data from the imaginary country Viraland, with clinical and epidemiological information for cases of feveriosis (fictional disease). The data is intended for use as part of the Spanish version of the case study "Analysis of routine surveillance of feveriosis" alongside the Spanish feveriosis_recent_es (linelist of feveriosis cases from Aug 31 - Sep 4, 2026 in Viraland).