Skip to contents

Russian version of the surveillance data for fictional disease feveriosis. Reported in fictional country Viraland in 2025 & 2026.

Usage

feveriosis_main_ru

Format

A dataframe with 427 rows and 13 columns.

Fictional data created by Applied Epi for training purposes

This is version 1.1

This dataset is Russian.

This dataset is licensed under CC by-NC-SA 4.0

Details

This is a linelist with fictional case-level data from the imaginary country Viraland, with clinical and epidemiological information for cases of feveriosis (fictional disease). The data is intended for use as part of the Russian version of the case study "Analysis of routine surveillance of feveriosis" alongside the Russian feveriosis_recent_ru (linelist of feveriosis cases from Aug 31 - Sep 4, 2026 in Viraland).