Skip to contents

French version of the recent surveillance data for fictional disease feveriosis. Reported in fictional country Viraland from August 31, 2026 to September 4, 2026.

Usage

feveriosis_recent_fr

Format

A dataframe with 28 rows and 12 columns.

Fictional data created by Applied Epi for training purposes

This is version 2.1

This dataset is French.

This dataset is licensed under CC by-NC-SA 4.0

Details

This is a linelist of a single week of case-level data of feveriosis (fictional data) from the imaginary country Viraland. The data is intended for use as part of the French version of the case study "Analysis of routine surveillance of feveriosis" alongside the French feveriosis_main_fr (compiled linelist of feveriosis cases from Jan 1 2025 - Aug 31, 2026 in Viraland).