Skip to contents

Country-level administrative boundaries for the African continent, for the GIS basics mapping example.

Usage

gis_africa_countries

Format

A simple features (sf) data frame with 51 rows and 65 columns

Natural Earth Admin-0 countries dataset. Natural Earth data is in the public domain and free to use without restriction.

Within this package the original dataset is gis_africa_countries.json

This is version 1.0.

This dataset is English.

This dataset is licensed under Public Domain

Details

Natural Earth Admin-0 country boundaries, filtered to the African continent (51 countries). Intended for use in choropleth/basemap exercises, e.g. alongside gis_covid_incidence.