Skip to contents

Fictional cumulative COVID-19 incidence by country, created for the GIS basics choropleth mapping example.

Usage

gis_covid_incidence

Format

A data frame with 238 rows and 3 columns

Fictional data created by Applied Epi for training purposes.

Within this package the original dataset is gis_covid_incidence.csv

This is version 1.0.

This dataset is English.

This dataset is licensed under CC by-NC-SA 4.0

Details

This is fictional data created for teaching purposes, simulating a global cumulative incidence table suitable for a world-map choropleth exercise.