Skip to contents

Subset of cleaned fictional Ebola Virus Disease case linelist data with additional admin-3 spatial join fields, repackaged for the GIS basics mapping example.

Usage

gis_linelist_cleaned_with_adm3

Format

A data frame with 1000 rows and 31 columns

This data is a cleaned version of linelist_cleaned_rds, which is cleaned using code in the epiRhandbook cleaning chapter.

Within this package the original dataset is gis_linelist_cleaned_with_adm3.rds

This is version 1.0.

This dataset is English.

This dataset is licensed under MIT

Details

Same content as linelist_cleaned_with_adm3. Intended for use alongside gis_population_sle_admpop_adm3_2020 in choropleth mapping exercises.

References

WHO Ebola Response Team. 2014. Ebola virus disease in West Africa–the first 9 months of the epidemic and forward projections. The New England journal of medicine 371:1481–1495 doi:10.1056/NEJMoa1411100