Population data at admin level 3 for Sierra Leone (GIS basics example)
gis_population_sle_admpop_adm3_2020.RdPopulation data at admin level 3 for Sierra Leone from Humanitarian Data Exchange, repackaged for the GIS basics mapping example.
This population data was downloaded from Humanitarian Data Exchange. No edits were made to this.
Within this package the original dataset is gis_population_sle_admpop_adm3_2020.csv
This is version 1.0.
This dataset is English.
This dataset is licensed under CC by-IGO
Details
Same content as sle_admpop_adm3_2020. Intended for use alongside gis_linelist_cleaned_with_adm3 in choropleth mapping exercises.