Cleaned fictional case linelist data (Excel) simulating properties from the West African Ebola outbreak of 2014
case_linelists_linelist_cleaned_excel.RdExcel file with cleaned version of fictional case linelist data simulating properties from the West African Ebola outbreak of 2014
This data is a cleaned version of case_linelists_linelist_raw, which is cleaned using code in the epiRhandbook cleaning chapter.
The original dataset is case_linelists_linelist_cleaned.xlsx
This is version 2.0.
This dataset is English.
This dataset is licensed under MIT
Details
This is fictional case-linelist which contains de-indentified individual level data
on clinical outcome, demographics and region. Same content as linelist_cleaned_excel,
repackaged under the case_linelists_ naming for this bundle.
References
WHO Ebola Response Team. 2014. Ebola virus disease in West Africa–the first 9 months of the epidemic and forward projections. The New England journal of medicine 371:1481–1495 doi:10.1056/NEJMoa1411100