Posterior estimated-reported-cases samples, fictional Ebola outbreak in Sierra Leone (2014) - epidemic models example
epidemic_models_estimated_reported_cases_samples.RdPosterior samples of estimated reported cases, unbundled from
epidemic_models_epinow_res ($estimated_reported_cases$samples) for
the epidemic models example.
The original dataset is epidemic_models_estimated_reported_cases_samples.rds
This is version 1.0.
This dataset is English.
This dataset is licensed under MIT
Details
See epidemic_models_epinow_res for the full model output this was extracted from.