Central Hospital subset, fictional Ebola Virus Disease case linelist (West Africa, 2014)
example_central_hospital.RdCentral Hospital subset of the cleaned fictional Ebola Virus Disease case linelist, one of six per-hospital files prepared for an iteration/loops example where multiple files are read in and combined.
Within this package the original dataset is example_central_hospital.csv.
This is version 1.0.
This dataset is English.
This dataset is licensed under MIT
Details
Row subset of example_hospital_linelists / hospital_linelists filtered to cases reported at Central Hospital. See also example_military_hospital, example_port_hospital, example_st_marks_maternity_hospital, example_missing, and example_other.
References
WHO Ebola Response Team. 2014. Ebola virus disease in West Africa–the first 9 months of the epidemic and forward projections. The New England journal of medicine 371:1481–1495 doi:10.1056/NEJMoa1411100