Combined hospital linelists example, fictional Ebola Virus Disease data (West Africa, 2014)
example_hospital_linelists.RdExcel file with the combined (all-hospital) cleaned version of fictional case linelist data simulating properties from the West African Ebola outbreak of 2014, prepared for an iteration/loops example folder.
This data is a cleaned version of example_case_linelist_2020_10_08. Within this package the original dataset is example_hospital_linelists.xlsx.
This is version 1.0.
This dataset is English.
This dataset is licensed under MIT
Details
Same content as hospital_linelists. Intended to be compared against the per-hospital splits example_central_hospital, example_military_hospital, example_port_hospital, example_st_marks_maternity_hospital, example_missing, and example_other, which together reconstruct this same data when row-bound.
References
WHO Ebola Response Team. 2014. Ebola virus disease in West Africa–the first 9 months of the epidemic and forward projections. The New England journal of medicine 371:1481–1495 doi:10.1056/NEJMoa1411100