Age/sex population proportions for Sierra Leone (GIS basics example)
gis_population_sle_population_statistics_sierraleone_2020.RdAge/sex population proportions for Sierra Leone, for the GIS basics population pyramid example.
This population data was downloaded from Humanitarian Data Exchange. No edits were made to this.
Within this package the original dataset is gis_population_sle_population_statistics_sierraleone_2020.xlsx
This is version 1.0.
This dataset is English.
This dataset is licensed under CC by-IGO
Details
Same source as sle_admpop_adm3_2020. Intended for use in population pyramid plotting exercises.