Cleaned fictional Ebola Virus Disease data simulating properties from the West African Ebola outbreak of 2014 (plain copy)
linelist_cleaned.RdCleaned version of fictional Ebola Virus Disease data simulating properties from the West African Ebola outbreak of 2014.
This data is a cleaned version of linelist_raw, which is cleaned using code in the epiRhandbook cleaning chapter.
The original dataset is linelist_cleaned.xlsx
This is version 2.0.
This dataset is English.
This dataset is licensed under MIT
Details
This is fictional case-linelist which contains de-indentified individual level data on clinical outcome, demographics and region. Same content as linelist_cleaned_excel.
References
WHO Ebola Response Team. 2014. Ebola virus disease in West Africa–the first 9 months of the epidemic and forward projections. The New England journal of medicine 371:1481–1495 doi:10.1056/NEJMoa1411100